==> spread-5.4.1.16-py3-none-any.whl: spread_dashboard/project/forms.py <==
from django import forms

from . import configs

IP_PATTERN = r'(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)_*(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)_*){3}'


class BaseForm(forms.ModelForm):
    @classmethod
    def of(cls, *args, **kwargs):
        # CommonForm(request.POST, instance=CommonForm.Meta.model())
        return cls(*args, instance=cls.Meta.model(**kwargs))


class CommonForm(BaseForm):
    class Meta:
        model = configs.Common
        fields = '__all__'
        widgets = {
            'host': forms.TextInput(attrs={'pattern': IP_PATTERN}),
            'password': forms.TextInput(attrs={'type': 'password'}),
            'projectID': forms.NumberInput(attrs={'readonly': True}),
        }


class CanAdapterForm(BaseForm):
    @classmethod
    def of(cls, index, *args):
        return super(CanAdapterForm, cls).of(index=index, *args)

    class Meta:
        model = configs.CanAdapter
        fields = '__all__'
        widgets = {
            'canInterface': forms.TextInput(attrs={'readonly': True}),
            'subtopicCan': forms.TextInput(attrs={'readonly': True}),
            'subtopicDali': forms.TextInput(attrs={'readonly': True}),
            'subtopicModbus': forms.TextInput(attrs={'readonly': True}),
            'pollRate': forms.NumberInput(attrs={'min': 0}),
        }


class KnxAdapterForm(BaseForm):
    @classmethod
    def of(cls, index, *args):
        return super(KnxAdapterForm, cls).of(index=index, *args)

    class Meta:
        model = configs.KnxNetIpAdapter
        fields = '__all__'
        widgets = {
            'subtopicKnx': forms.TextInput(attrs={'readonly': True}),
            'remoteHost': forms.TextInput(attrs={'pattern': IP_PATTERN}),
            'tickResolution': forms.NumberInput(attrs={'min': 5, 'max': 50}),
            'firstConnectTimeout': forms.NumberInput(attrs={'min': 500, 'max': 1500}),
            'otherConnectTimeout': forms.NumberInput(attrs={'min': 50, 'max': 500}),
        }


class _ManagerForm(BaseForm):
    @classmethod
    def of(cls, bus, *args):
        return super(_ManagerForm, cls).of(bus=bus, *args)


class DaliManagerForm(_ManagerForm):
    class Meta:
        model = configs.DaliManager
        fields = '__all__'
        widgets = {
            'managerID': forms.NumberInput(attrs={'readonly': True}),
            'query_level_delay': forms.NumberInput(attrs={'step': 0.1, 'min': 0})
        }


class KnxManagerForm(_ManagerForm):
    class Meta:
        model = configs.KnxManager
        fields = '__all__'
        widgets = {
            'managerID': forms.NumberInput(attrs={'readonly': True}),
        }


class MercuryManagerForm(_ManagerForm):
    class Meta:
        model = configs.MercuryManager
        fields = '__all__'
        widgets = {
            'managerID': forms.NumberInput(attrs={'readonly': True}),
            'hexed': forms.TextInput()
        }


class TcpAdapterForm(BaseForm):
    @classmethod
    def of(cls, bus, *args):
        return super(TcpAdapterForm, cls).of(bus=bus, *args)

    class Meta:
        model = configs.TcpAdapter
        fields = '__all__'
        widgets = {
            'subtopic': forms.TextInput(attrs={'readonly': True}),
            'host': forms.TextInput(attrs={'pattern': IP_PATTERN}),
            # 'timeout': forms.NumberInput(min_value=0.1),
            # 'killTimeout': forms.NumberInput(min_value=0.1),
        }


class LomManagerForm(BaseForm):
    @classmethod
    def of(cls, *args):
        return super(LomManagerForm, cls).of(*args)

    class Meta:
        model = configs.LomManager
        fields = '__all__'
        widgets = {
            'managerID': forms.NumberInput(attrs={'readonly': True}),
        }


class FrontierForm(BaseForm):
    class Meta:
        model = configs.Frontier
        fields = '__all__'
        widgets = {
            'serverID': forms.NumberInput(attrs={'readonly': True}),
        }


class SchedulerForm(BaseForm):
    class Meta:
        model = configs.Scheduler
        fields = '__all__'
        widgets = {
            'tasks': forms.TextInput(attrs={'readonly': True}),
            'calendar': forms.TextInput(attrs={'readonly': True}),
        }


class CyclerForm(BaseForm):
    class Meta:
        model = configs.Cycler
        fields = '__all__'


class ScripterForm(BaseForm):
    class Meta:
        model = configs.Scripter
        fields = '__all__'
        widgets = {
            'triggers': forms.TextInput(attrs={'readonly': True}),
            'calendar': forms.TextInput(attrs={'readonly': True}),
        }


class ProjectorForm(BaseForm):
    class Meta:
        model = configs.Projector
        fields = '__all__'


class EventsSqliteForm(BaseForm):
    class Meta:
        model = configs.EventsSqlite
        fields = '__all__'
        widgets = {
            'tickRate': forms.NumberInput(attrs={'min': 500, 'max': 9000}),
        }


class LightingEquipmentForm(BaseForm):
    class Meta:
        model = configs.LightingEquipment
        fields = '__all__'


class ShadingEquipmentForm(BaseForm):
    class Meta:
        model = configs.ShadingEquipment
        fields = '__all__'


class DashboardForm(BaseForm):
    class Meta:
        model = configs.Dashboard
        fields = '__all__'
        widgets = {
            'port': forms.TextInput(attrs={'readonly': True}),
        }

==> spread-5.5.0.34-py3-none-any.whl: spread_dashboard/project/forms.py <==
from django import forms

from . import configs

IP_PATTERN = r'(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)_*(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)_*){3}'


class BaseForm(forms.ModelForm):
    @classmethod
    def of(cls, *args, **kwargs):
        # CommonForm(request.POST, instance=CommonForm.Meta.model())
        return cls(*args, instance=cls.Meta.model(**kwargs))


class CommonForm(BaseForm):
    class Meta:
        model = configs.Common
        fields = '__all__'
        widgets = {
            'host': forms.TextInput(attrs={'pattern': IP_PATTERN}),
            'password': forms.TextInput(attrs={'type': 'password'}),
            'projectID': forms.NumberInput(attrs={'readonly': True}),
        }


class CanAdapterForm(BaseForm):
    @classmethod
    def of(cls, index, *args):
        return super(CanAdapterForm, cls).of(index=index, *args)

    class Meta:
        model = configs.CanAdapter
        fields = '__all__'
        widgets = {
            'canInterface': forms.TextInput(attrs={'readonly': True}),
            'subtopicCan': forms.TextInput(attrs={'readonly': True}),
            'subtopicDali': forms.TextInput(attrs={'readonly': True}),
            'subtopicModbus': forms.TextInput(attrs={'readonly': True}),
            'pollRate': forms.NumberInput(attrs={'min': 0}),
        }


class KnxAdapterForm(BaseForm):
    @classmethod
    def of(cls, index, *args):
        return super(KnxAdapterForm, cls).of(index=index, *args)

    class Meta:
        model = configs.KnxNetIpAdapter
        fields = '__all__'
        widgets = {
            'subtopicKnx': forms.TextInput(attrs={'readonly': True}),
            'remoteHost': forms.TextInput(attrs={'pattern': IP_PATTERN}),
            'tickResolution': forms.NumberInput(attrs={'min': 5, 'max': 50}),
            'firstConnectTimeout': forms.NumberInput(attrs={'min': 500, 'max': 1500}),
            'otherConnectTimeout': forms.NumberInput(attrs={'min': 50, 'max': 500}),
        }


class _ManagerForm(BaseForm):
    @classmethod
    def of(cls, bus, *args):
        return super(_ManagerForm, cls).of(bus=bus, *args)


class DaliManagerForm(_ManagerForm):
    class Meta:
        model = configs.DaliManager
        fields = '__all__'
        widgets = {
            'managerID': forms.NumberInput(attrs={'readonly': True}),
            'query_level_delay': forms.NumberInput(attrs={'step': 0.1, 'min': 0}),
            'sensorStatusFrequency': forms.NumberInput(attrs={'step': 1, 'min': 1})
        }


class KnxManagerForm(_ManagerForm):
    class Meta:
        model = configs.KnxManager
        fields = '__all__'
        widgets = {
            'managerID': forms.NumberInput(attrs={'readonly': True}),
        }


class MercuryManagerForm(_ManagerForm):
    class Meta:
        model = configs.MercuryManager
        fields = '__all__'
        widgets = {
            'managerID': forms.NumberInput(attrs={'readonly': True}),
            'hexed': forms.TextInput()
        }


class BolidManagerForm(_ManagerForm):
    class Meta:
        model = configs.BolidManager
        fields = '__all__'
        widgets = {
            'managerID': forms.NumberInput(attrs={'readonly': True}),
        }


class TcpAdapterForm(BaseForm):
    @classmethod
    def of(cls, bus, *args):
        return super(TcpAdapterForm, cls).of(bus=bus, *args)

    class Meta:
        model = configs.TcpAdapter
        fields = '__all__'
        widgets = {
            'subtopic': forms.TextInput(attrs={'readonly': True}),
            'host': forms.TextInput(attrs={'pattern': IP_PATTERN}),
            # 'timeout': forms.NumberInput(min_value=0.1),
            # 'killTimeout': forms.NumberInput(min_value=0.1),
        }


class LomManagerForm(BaseForm):
    @classmethod
    def of(cls, *args):
        return super(LomManagerForm, cls).of(*args)

    class Meta:
        model = configs.LomManager
        fields = '__all__'
        widgets = {
            'managerID': forms.NumberInput(attrs={'readonly': True}),
        }


class FrontierForm(BaseForm):
    class Meta:
        model = configs.Frontier
        fields = '__all__'
        widgets = {
            'serverID': forms.NumberInput(attrs={'readonly': True}),
        }


class SchedulerForm(BaseForm):
    class Meta:
        model = configs.Scheduler
        fields = '__all__'
        widgets = {
            'tasks': forms.TextInput(attrs={'readonly': True}),
            'calendar': forms.TextInput(attrs={'readonly': True}),
        }


class CyclerForm(BaseForm):
    class Meta:
        model = configs.Cycler
        fields = '__all__'


class ScripterForm(BaseForm):
    class Meta:
        model = configs.Scripter
        fields = '__all__'
        widgets = {
            'triggers': forms.TextInput(attrs={'readonly': True}),
            'calendar': forms.TextInput(attrs={'readonly': True}),
        }


class ProjectorForm(BaseForm):
    class Meta:
        model = configs.Projector
        fields = '__all__'


class EventsSqliteForm(BaseForm):
    class Meta:
        model = configs.EventsSqlite
        fields = '__all__'
        widgets = {
            'tickRate': forms.NumberInput(attrs={'min': 500, 'max': 9000}),
        }


class LightingEquipmentForm(BaseForm):
    class Meta:
        model = configs.LightingEquipment
        fields = '__all__'


class ShadingEquipmentForm(BaseForm):
    class Meta:
        model = configs.ShadingEquipment
        fields = '__all__'


class AlarmEquipmentForm(BaseForm):
    class Meta:
        model = configs.AlarmEquipment
        fields = '__all__'


class DashboardForm(BaseForm):
    class Meta:
        model = configs.Dashboard
        fields = '__all__'
        widgets = {
            'port': forms.TextInput(attrs={'readonly': True}),
        }
